==> savane-1.3+2.tar.gz: savane-1.3+2/frontend/php/account/pending.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: pending.php 4567 2005-06-30 17:19:37Z toddy $
#
#
#
# Copyright 1999-2000 (c) The SourceForge Crew
#
#
#  Copyright (C) 2000, 2001, 2002 Free Software Foundation
#
# The Savane project is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# The Savane project is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the Savane project; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
#
#
#

require "../include/pre.php";
$HTML->header(array(title=>_("Pending Account")));


echo '<h3>'._("Pending Account").'</h3>';

echo '<p>'._("Your account is currently pending your email confirmation. Visiting the link sent to you in this email will activate your account.").'</p>';

echo '<p>'._("If you need this email resent, please click below and a confirmation email will be sent to the email address you provided in registration.").'</p>';

echo '<p><a href="pending-resend.php?form_user='.$form_user.'">['._("Resend Confirmation Email").']</a>';
echo '<br /><a href="/">';
printf (_("[Return to %s]"),$GLOBALS['sys_name']);
echo '</a></p>';

$HTML->footer(array());

?>

==> savane-2.0.tar.gz: savane-2.0/frontend/php/account/pending.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: pending.php 5788 2006-09-13 15:59:38Z yeupou $
#
#
#
# Copyright 1999-2000 (c) The SourceForge Crew
#
#
#  Copyright (C) 2000, 2001, 2002 Free Software Foundation
#
# The Savane project is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# The Savane project is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the Savane project; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
#
#
#

require "../include/pre.php";

# Logged users have no business here
if (user_isloggedin())
{ session_redirect($GLOBALS['sys_home']."my/"); }


$HTML->header(array(title=>_("Pending Account")));


echo '<h3>'._("Pending Account").'</h3>';

echo '<p>'._("Your account is currently pending your email confirmation. Visiting the link sent to you in this email will activate your account.").'</p>';

echo '<p>'._("If you need this email resent, please click below and a confirmation email will be sent to the email address you provided in registration.").'</p>';

echo '<p><a href="pending-resend.php?form_user='.$form_user.'">['._("Resend Confirmation Email").']</a>';
echo '<br /><a href="/">';
printf (_("[Return to %s]"),$GLOBALS['sys_name']);
echo '</a></p>';

$HTML->footer(array());

?>
